PhonePeConfig class

Constructors

PhonePeConfig({String? callBackUrl, String? baseUrl, String? saltKey, num? saltIndex, String? appName, String? merchanId, String? redirectUrl})
PhonePeConfig.fromJson(Map<String, dynamic> json)

Properties

appName String?
getter/setter pair
baseUrl String?
getter/setter pair
callBackUrl String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchanId String?
getter/setter pair
redirectUrl String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saltIndex num?
getter/setter pair
saltKey String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited