UpiParams class

Constructors

UpiParams({String? packageName, String? merchantTransactionId, String? merchantUserId, String? merchantId, int? amount, String? mobileNumber, String? callbackUrl, String? salt, int? saltIndex})
UpiParams.fromJson(Map<String, dynamic> json)

Properties

amount int?
getter/setter pair
callbackUrl String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchantId String?
getter/setter pair
merchantTransactionId String?
getter/setter pair
merchantUserId String?
getter/setter pair
mobileNumber String?
getter/setter pair
packageName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt String?
getter/setter pair
saltIndex int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited